@@ -34,6 +34,7 @@ __all__ = [
     "WhenNotMatchedClause",
     "QueryRecord",
     "QueryHistory",
+    "AsyncJob",
 ]
 
 
@@ -42,6 +43,7 @@ from snowflake.snowpark.version import VERSION
 __version__ = ".".join(str(x) for x in VERSION if x is not None)
 
 
+from snowflake.snowpark.async_job import AsyncJob
 from snowflake.snowpark.column import CaseExpr, Column
 from snowflake.snowpark.dataframe import DataFrame
 from snowflake.snowpark.dataframe_na_functions import DataFrameNaFunctions
