@@ -1,7 +1,7 @@
 #
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
-from typing import List, Optional, Set
+from typing import Optional, Set
 
 from snowflake.snowpark._internal.analyzer.expression import (
     Expression,
@@ -22,9 +22,6 @@ class UnaryExpression(Expression):
         self.children = [child]
         self.datatype = self.child.datatype
 
-    def children(self) -> List[Expression]:
-        return self.children
-
     def __str__(self):
         return (
             f"{self.sql_operator} {self.child}"
@@ -62,7 +59,7 @@ class IsNotNull(UnaryExpression):
 
 
 class IsNaN(UnaryExpression):
-    sql_operator = "= 'NaN'"
+    sql_operator = "= 'NAN'"
     operator_first = False
 
 
