@@ -81,7 +81,7 @@ def _to_col_if_lit(
         return col
     elif isinstance(col, VALID_PYTHON_TYPES_FOR_LITERAL_VALUE):
         return Column(Literal(col))
-    else:
+    else:  # pragma: no cover
         raise TypeError(
             f"'{func_name}' expected Column, DataFrame, Iterable or LiteralType, got: {type(col)}"
         )
@@ -116,7 +116,7 @@ def _to_col_if_str_or_int(col: Union[ColumnOrName, int], func_name: str) -> "Col
         return Column(col)
     elif isinstance(col, int):
         return Column(Literal(col))
-    else:
+    else:  # pragma: no cover
         raise TypeError(
             f"'{func_name.upper()}' expected Column, int or str, got: {type(col)}"
         )
@@ -218,10 +218,11 @@ class Column:
                 self._expression = UnresolvedAttribute(quote_name(expr))
         elif isinstance(expr, Expression):
             self._expression = expr
-        else:
+        else:  # pragma: no cover
             raise TypeError("Column constructor only accepts str or expression.")
 
     def __getitem__(self, field: Union[str, int]) -> "Column":
+        """Accesses an element of ARRAY column by ordinal position, or an element of OBJECT column by key."""
         if isinstance(field, str):
             return Column(SubfieldString(self._expression, field))
         elif isinstance(field, int):
@@ -454,14 +455,14 @@ class Column:
         return Column(And(self._expression, Column._to_expr(other)))
 
     def __rand__(self, other: "Column") -> "Column":
-        return Column(And(Column._to_expr(other), self._expression))
+        return Column(And(Column._to_expr(other), self._expression))  # pragma: no cover
 
     def __or__(self, other: "Column") -> "Column":
         """Or."""
         return Column(Or(self._expression, Column._to_expr(other)))
 
     def __ror__(self, other: "Column") -> "Column":
-        return Column(And(Column._to_expr(other), self._expression))
+        return Column(And(Column._to_expr(other), self._expression))  # pragma: no cover
 
     def __invert__(self) -> "Column":
         """Unary not."""
@@ -605,7 +606,7 @@ class Column:
         return f"Column[{self._expression}]"
 
     def __repr__(self):
-        return f"Column({self._expression})"
+        return f"Column({self._expression})"  # pragma: no cover
 
     def as_(self, alias: str) -> "Column":
         """Returns a new renamed Column. Alias of :func:`name`."""
@@ -725,6 +726,7 @@ class Column:
     isNull = is_null
     eqNullSafe = equal_null
     getName = get_name
+    getItem = __getitem__
 
 
 class CaseExpr(Column):
@@ -752,9 +754,7 @@ class CaseExpr(Column):
         super().__init__(expr)
         self._branches = expr.branches
 
-    def when(
-        self, condition: ColumnOrSqlExpr, value: ColumnOrLiteral
-    ) -> "CaseExpr":
+    def when(self, condition: ColumnOrSqlExpr, value: ColumnOrLiteral) -> "CaseExpr":
         """
         Appends one more WHEN condition to the CASE expression.
 
