@@ -121,6 +121,9 @@ class GroupingSets:
 class RelationalGroupedDataFrame:
     """Represents an underlying DataFrame with rows that are grouped by common values.
     Can be used to define aggregations on these grouped DataFrames.
+
+    See also:
+        :meth:`snowflake.snowpark.DataFrame.agg`.
     """
 
     def __init__(
@@ -182,7 +185,7 @@ class RelationalGroupedDataFrame:
                 agg_exprs,
                 self._df._select_statement or self._df._plan,
             )
-        else:
+        else:  # pragma: no cover
             raise TypeError(f"Wrong group by type {self._group_type}")
 
         if self._df._select_statement:
