@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
-"""Stored procedures in Snowpark."""
+"""Stored procedures in Snowpark. Refer to :class:`~snowflake.snowpark.stored_procedure.StoredProcedure` for details and sample code."""
 import sys
 import typing
 from types import ModuleType
@@ -108,7 +108,10 @@ class StoredProcedureRegistration:
           function on the Snowflake server during stored procedure creation. During the serialization, the
           global variables used in the Python function will be serialized into the bytecode,
           but only the name of the module object or any objects from a module that are used in the
-          Python function will be serialized. During the deserialization, Python will look up the
+          Python function will be serialized. If the size of the serialized bytecode is over 8K bytes, it will be uploaded to a stage location as a Python file.
+          If it's under 8K, it will be added to the `Stored Procedure in-line code <https://docs.snowflake.com/en/sql-reference/stored-procedures-python.html#choosing-to-create-a-stored-procedure-with-in-line-code-or-with-code-uploaded-from-a-stage>`__.
+
+          During the deserialization, Python will look up the
           corresponding modules and objects by names.
 
           Details could be found in :class:`snowflake.snowpark.udf.UDFRegistration`.
@@ -332,6 +335,7 @@ class StoredProcedureRegistration:
         replace: bool = False,
         parallel: int = 4,
         execute_as: typing.Literal["caller", "owner"] = "owner",
+        strict: bool = False,
         *,
         statement_params: Optional[Dict[str, str]] = None,
     ) -> StoredProcedure:
@@ -385,6 +389,9 @@ class StoredProcedureRegistration:
                 large stored procedure files.
             execute_as: What permissions should the procedure have while executing. This
                 supports caller, or owner for now.
+            strict: Whether the created stored procedure is strict. A strict stored procedure will not invoke
+                the stored procedure if any input is null. Instead, a null value will always be returned. Note
+                that the stored procedure might still return null for non-null inputs.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
 
         See Also:
@@ -420,6 +427,7 @@ class StoredProcedureRegistration:
             packages,
             replace,
             parallel,
+            strict,
             statement_params=statement_params,
             execute_as=execute_as,
             api_call_source="StoredProcedureRegistration.register",
@@ -438,6 +446,7 @@ class StoredProcedureRegistration:
         packages: Optional[List[Union[str, ModuleType]]] = None,
         replace: bool = False,
         parallel: int = 4,
+        strict: bool = False,
         *,
         statement_params: Optional[Dict[str, str]] = None,
     ) -> StoredProcedure:
@@ -495,6 +504,9 @@ class StoredProcedureRegistration:
                 command. The default value is 4 and supported values are from 1 to 99.
                 Increasing the number of threads can improve performance when uploading
                 large stored procedure files.
+            strict: Whether the created stored procedure is strict. A strict stored procedure will not invoke
+                the stored procedure if any input is null. Instead, a null value will always be returned. Note
+                that the stored procedure might still return null for non-null inputs.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
 
         Note::
@@ -523,6 +535,7 @@ class StoredProcedureRegistration:
             packages,
             replace,
             parallel,
+            strict,
             statement_params=statement_params,
             api_call_source="StoredProcedureRegistration.register_from_file",
         )
@@ -538,6 +551,7 @@ class StoredProcedureRegistration:
         packages: Optional[List[Union[str, ModuleType]]],
         replace: bool,
         parallel: int,
+        strict: bool,
         *,
         statement_params: Optional[Dict[str, str]] = None,
         execute_as: typing.Literal["caller", "owner"] = "owner",
@@ -601,6 +615,7 @@ class StoredProcedureRegistration:
                 inline_python_code=code,
                 execute_as=execute_as,
                 api_call_source=api_call_source,
+                strict=strict,
             )
         # an exception might happen during registering a stored procedure
         # (e.g., a dependency might not be found on the stage),
